summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/options.h
diff options
context:
space:
mode:
authorMatthew Cline <zelgadis@sourceforge.net>2009-11-15 04:05:31 -0800
committerMatthew Cline <zelgadis@sourceforge.net>2009-11-15 04:05:31 -0800
commit3be53369f544187af7bb88b1ee284ab1348f32af (patch)
tree2fa8af73c0cf9ea2be3df7159cbf9163799c8958 /crawl-ref/source/options.h
parentdf940b3d40577cd05d71ebe7613f0dec1f115e91 (diff)
downloadcrawl-ref-3be53369f544187af7bb88b1ee284ab1348f32af.tar.gz
crawl-ref-3be53369f544187af7bb88b1ee284ab1348f32af.zip
luaterp (&^T): load files via terp_file option
You can now specify Lua files to be loaded for use in the wizard Lua interpreter via "terp_file = file_path" in your init file. These files will be run in the context of dlua, as opposed to the clua context of files included with "lua_file = file_path".
Diffstat (limited to 'crawl-ref/source/options.h')
-rw-r--r--crawl-ref/source/options.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/options.h b/crawl-ref/source/options.h
index 3abd9bc1e6..b344176e99 100644
--- a/crawl-ref/source/options.h
+++ b/crawl-ref/source/options.h
@@ -168,7 +168,8 @@ public:
std::string pizza;
#ifdef WIZARD
- int wiz_mode; // yes, no, never in wiz mode to start
+ int wiz_mode; // no, never, start in wiz mode
+ std::vector<std::string> terp_files; // Lua files to load for luaterp
#endif
// internal use only: